summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/widgets/tqhbuttongroup.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-10 12:13:27 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-10 12:13:27 -0500
commitd296f1d337dabfeae5191955fdadb874965dbbe9 (patch)
tree1a4b3b4cca01f2ea77eee2497297219d60e9bbd4 /tqtinterface/qt4/src/widgets/tqhbuttongroup.cpp
parenteaa7ee2e0bbca40ba3173c4304f81957e8964291 (diff)
downloadexperimental-d296f1d337dabfeae5191955fdadb874965dbbe9.tar.gz
experimental-d296f1d337dabfeae5191955fdadb874965dbbe9.zip
rename the following methods:
tqparent parent tqmask mask
Diffstat (limited to 'tqtinterface/qt4/src/widgets/tqhbuttongroup.cpp')
-rw-r--r--tqtinterface/qt4/src/widgets/tqhbuttongroup.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/tqtinterface/qt4/src/widgets/tqhbuttongroup.cpp b/tqtinterface/qt4/src/widgets/tqhbuttongroup.cpp
index 29af0a9..3f02794 100644
--- a/tqtinterface/qt4/src/widgets/tqhbuttongroup.cpp
+++ b/tqtinterface/qt4/src/widgets/tqhbuttongroup.cpp
@@ -64,24 +64,24 @@
/*!
Constructs a horizontal button group with no title.
- The \a tqparent and \a name arguments are passed to the TQWidget
+ The \a parent and \a name arguments are passed to the TQWidget
constructor.
*/
-TQHButtonGroup::TQHButtonGroup( TQWidget *tqparent, const char *name )
- : TQButtonGroup( 1, Qt::Vertical /* sic! */, tqparent, name )
+TQHButtonGroup::TQHButtonGroup( TQWidget *parent, const char *name )
+ : TQButtonGroup( 1, Qt::Vertical /* sic! */, parent, name )
{
}
/*!
Constructs a horizontal button group with the title \a title.
- The \a tqparent and \a name arguments are passed to the TQWidget
+ The \a parent and \a name arguments are passed to the TQWidget
constructor.
*/
-TQHButtonGroup::TQHButtonGroup( const TQString &title, TQWidget *tqparent,
+TQHButtonGroup::TQHButtonGroup( const TQString &title, TQWidget *parent,
const char *name )
- : TQButtonGroup( 1, Qt::Vertical /* sic! */, title, tqparent, name )
+ : TQButtonGroup( 1, Qt::Vertical /* sic! */, title, parent, name )
{
}